@@@@@@@
Credits
@@@@@@@

.. |Landon Bouma| replace:: Landon Bouma
.. _Landon Bouma: https://github.com/landonb

.. |Tally Bark LLC| replace:: Tally Bark LLC
.. _Tally Bark LLC: https://www.tallybark.com/

###############################
``dob-bright`` (2018 — Present)
###############################

Project Lead
============

* |Landon Bouma|_ for |Tally Bark LLC|_ ``<landonb.dob-bright@tallybark[.]com>``

